SciSalt
=======

This project has slowly grown from frequently-used code snippets. The
main objective is to create a collection of interconnected methods
frequently needed to visualize and analyze data using Numpy, Scipy,
Matplotlib, and PyQt.

It is broken down into the modules it primarily assists with, although
there may be connections between modules. The documentation informs
how a typical user may access it.

Documentation can be found at:

http://scisalt.readthedocs.org
